@@ -1051,11 +1051,6 @@ class IOPlacement(OpenROADStep):
                 Optional[Path],
                 "Path to a custom pin configuration file.",
             ),
-            Variable(
-                "FP_DEF_TEMPLATE",
-                Optional[Path],
-                "Points to the DEF file to be used as a template.",
-            ),
             Variable(
                 "FP_IO_VLENGTH",
                 Optional[Decimal],
@@ -1327,11 +1322,6 @@ class GlobalPlacementSkipIO(_GlobalPlacement):
             default="matching",
             deprecated_names=[("FP_IO_MODE", _migrate_ppl_mode)],
         ),
-        Variable(
-            "FP_DEF_TEMPLATE",
-            Optional[Path],
-            "Points to the DEF file to be used as a template.",
-        ),
     ]
 
     def run(self, state_in: State, **kwargs) -> Tuple[ViewsUpdate, MetricsUpdate]:
